@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <glib/gmain.h>
+#include <glib.h>
 #include <gmodule.h>
 #include <libgda/libgda.h>
 #include <glib/gi18n-lib.h>
@@ -27,7 +27,7 @@
 
 #include <libgda/binreloc/gda-binreloc.h>
 #include <sql-parser/gda-sql-parser.h>
-#include <libgda/gda-error.h>
+#include <libgda/gda-types.h>
 
 /* global variables */
 xmlDtdPtr       gda_array_dtd = NULL;
