@@ -1,6 +1,6 @@
 /* 
  * GDA common library
- * Copyright (C) 2007 - 2010 The GNOME Foundation.
+ * Copyright (C) 2007 The GNOME Foundation.
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -70,7 +70,7 @@ gda_vconnection_data_model_class_init (GdaVconnectionDataModelClass *klass)
 }
 
 static void
-gda_vconnection_data_model_init (GdaVconnectionDataModel *cnc, G_GNUC_UNUSED GdaVconnectionDataModelClass *klass)
+gda_vconnection_data_model_init (GdaVconnectionDataModel *cnc, GdaVconnectionDataModelClass *klass)
 {
 	cnc->priv = g_new (GdaVconnectionDataModelPrivate, 1);
 	cnc->priv->table_data_list = NULL;
@@ -114,8 +114,7 @@ gda_vconnection_data_model_get_type (void)
 				NULL, NULL,
 				sizeof (GdaVconnectionDataModel),
 				0,
-				(GInstanceInitFunc) gda_vconnection_data_model_init,
-				0
+				(GInstanceInitFunc) gda_vconnection_data_model_init
 			};
 			
 		g_static_mutex_lock (&registering);
@@ -131,7 +130,7 @@ gda_vconnection_data_model_get_type (void)
 static void
 gda_vconnection_data_model_set_property (GObject *object,
 					 guint param_id,
-					 G_GNUC_UNUSED const GValue *value,
+					 const GValue *value,
 					 GParamSpec *pspec)
 {
         GdaVconnectionDataModel *cnc;
@@ -140,7 +139,6 @@ gda_vconnection_data_model_set_property (GObject *object,
         if (cnc->priv) {
                 switch (param_id) {
 		default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
                 }
         }
@@ -149,7 +147,7 @@ gda_vconnection_data_model_set_property (GObject *object,
 static void
 gda_vconnection_data_model_get_property (GObject *object,
 					 guint param_id,
-					 G_GNUC_UNUSED GValue *value,
+					 GValue *value,
 					 GParamSpec *pspec)
 {
         GdaVconnectionDataModel *cnc;
@@ -158,7 +156,6 @@ gda_vconnection_data_model_get_property (GObject *object,
         if (cnc->priv) {
 		switch (param_id) {
 		default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
 		}
         }
@@ -233,7 +230,7 @@ gda_vconnection_data_model_add (GdaVconnectionDataModel *cnc, GdaVconnectionData
 	g_return_val_if_fail (GDA_IS_VCONNECTION_DATA_MODEL (cnc), FALSE);
 	g_return_val_if_fail (table_name && *table_name, FALSE);
 	g_return_val_if_fail (spec, FALSE);
-	g_return_val_if_fail (spec->data_model || (spec->create_columns_func && (spec->create_model_func || spec->create_filtered_model_func)), FALSE);
+	g_return_val_if_fail (spec->data_model || (spec->create_columns_func && spec->create_model_func), FALSE);
 	if (spec->data_model)
 		g_return_val_if_fail (GDA_IS_DATA_MODEL (spec->data_model), FALSE);
 
@@ -253,11 +250,11 @@ gda_vconnection_data_model_add (GdaVconnectionDataModel *cnc, GdaVconnectionData
 	/* actually create the virtual table in @cnc */
 	prov = (GdaVirtualProvider *) gda_connection_get_provider (GDA_CONNECTION (cnc));
 	str = g_strdup_printf ("CREATE VIRTUAL TABLE %s USING %s ('%s')", table_name, G_OBJECT_TYPE_NAME (prov), td->unique_name);
-	rc = SQLITE3_CALL (sqlite3_exec) (scnc->connection, str, NULL, 0, &zErrMsg);
+	rc = sqlite3_exec (scnc->connection, str, NULL, 0, &zErrMsg);
 	g_free (str);
 	if (rc != SQLITE_OK) {
 		g_set_error (error, 0, 0, "%s", zErrMsg);
-		SQLITE3_CALL (sqlite3_free) (zErrMsg);
+		sqlite3_free (zErrMsg);
 		gda_vconnection_data_model_table_data_free (td);
 		cnc->priv->table_data_list = g_slist_remove (cnc->priv->table_data_list, td);
 		retval = FALSE;
@@ -311,12 +308,12 @@ gda_vconnection_data_model_remove (GdaVconnectionDataModel *cnc, const gchar *ta
 	
 	prov = (GdaVirtualProvider *) gda_connection_get_provider (GDA_CONNECTION (cnc));
 	str = g_strdup_printf ("DROP TABLE %s", td->table_name);
-	rc = SQLITE3_CALL (sqlite3_exec) (scnc->connection, str, NULL, 0, &zErrMsg);
+	rc = sqlite3_exec (scnc->connection, str, NULL, 0, &zErrMsg);
 	g_free (str);
 
 	if (rc != SQLITE_OK) {
 		g_set_error (error, 0, 0, "%s", zErrMsg);
-		SQLITE3_CALL (sqlite3_free) (zErrMsg);
+		sqlite3_free (zErrMsg);
 		return FALSE;
 	}
 	else {
@@ -385,7 +382,7 @@ gda_vconnection_data_model_get_table_name (GdaVconnectionDataModel *cnc, GdaData
  * gda_vconnection_data_model_foreach
  * @cnc: a #GdaVconnectionDataModel connection
  * @func: a #GdaVconnectionDataModelFunc function pointer
- * @data: data to pass to @func calls
+ * @data: data to pass to @cunc calls
  *
  * Call @func for each table in @cnc. 
  *
@@ -452,8 +449,6 @@ gda_vconnection_get_table_data_by_model (GdaVconnectionDataModel *cnc, GdaDataMo
 void
 gda_vconnection_data_model_table_data_free (GdaVConnectionTableData *td)
 {
-	ParamType i;
-
 	if (td->real_model)
 		g_object_unref (td->real_model);
 	if (td->columns) {
@@ -464,11 +459,5 @@ gda_vconnection_data_model_table_data_free (GdaVConnectionTableData *td)
 	g_free (td->unique_name);
 	if (td->spec_free_func)
 		td->spec_free_func (td->spec);
-	for (i = 0; i < PARAMS_NB; i++) {
-		if (td->modif_params[i])
-			g_object_unref (td->modif_params[i]);
-		if (td->modif_stmt[i])
-			g_object_unref (td->modif_stmt[i]);
-	}
 	g_free (td);
 }
