@@ -497,11 +497,7 @@ real_open_connection (const gchar  *host,
 						  (port > 0) ? port : 0,
 						  socket, flags);
 	if (!return_mysql || mysql != return_mysql) {
-#if GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION < 18
 		g_set_error (error, 0, 0, "%s", mysql_error (mysql));
-#else
-		g_set_error_literal (error, 0, 0, mysql_error (mysql));
-#endif
 		g_free (mysql);
 		mysql = NULL;
 	}
@@ -801,12 +797,12 @@ gda_mysql_provider_supports_operation (GdaServerProvider       *provider,
         case GDA_SERVER_OPERATION_CREATE_TABLE:
         case GDA_SERVER_OPERATION_DROP_TABLE:
         case GDA_SERVER_OPERATION_RENAME_TABLE:
-        case GDA_SERVER_OPERATION_COMMENT_TABLE:
+
         case GDA_SERVER_OPERATION_ADD_COLUMN:
-	case GDA_SERVER_OPERATION_DROP_COLUMN:
-	case GDA_SERVER_OPERATION_COMMENT_COLUMN:
+
         case GDA_SERVER_OPERATION_CREATE_INDEX:
         case GDA_SERVER_OPERATION_DROP_INDEX:
+
         case GDA_SERVER_OPERATION_CREATE_VIEW:
         case GDA_SERVER_OPERATION_DROP_VIEW:
 		return TRUE;
@@ -819,7 +815,7 @@ gda_mysql_provider_supports_operation (GdaServerProvider       *provider,
  * Create operation request
  *
  * Creates a #GdaServerOperation. The following code is generic and should only be changed
- * if some further initialization is required, or if operation's contents is dependent on @cnc
+ * if some further initialization is required, or if operation's contents is dependant on @cnc
  */
 static GdaServerOperation *
 gda_mysql_provider_create_operation (GdaServerProvider       *provider,
@@ -916,18 +912,12 @@ gda_mysql_provider_render_operation (GdaServerProvider   *provider,
         case GDA_SERVER_OPERATION_RENAME_TABLE:
 		sql = gda_mysql_render_RENAME_TABLE (provider, cnc, op, error);
 		break;
-        case GDA_SERVER_OPERATION_COMMENT_TABLE:
-		sql = gda_mysql_render_COMMENT_TABLE (provider, cnc, op, error);
-		break;
         case GDA_SERVER_OPERATION_ADD_COLUMN:
 		sql = gda_mysql_render_ADD_COLUMN (provider, cnc, op, error);
 		break;
 	case GDA_SERVER_OPERATION_DROP_COLUMN:
 		sql = gda_mysql_render_DROP_COLUMN (provider, cnc, op, error);
 		break;
-	case GDA_SERVER_OPERATION_COMMENT_COLUMN:
-		sql = gda_mysql_render_COMMENT_COLUMN (provider, cnc, op, error);
-		break;
         case GDA_SERVER_OPERATION_CREATE_INDEX:
 		sql = gda_mysql_render_CREATE_INDEX (provider, cnc, op, error);
 		break;
@@ -938,8 +928,8 @@ gda_mysql_provider_render_operation (GdaServerProvider   *provider,
 		sql = gda_mysql_render_CREATE_VIEW (provider, cnc, op, error);
 		break;
         case GDA_SERVER_OPERATION_DROP_VIEW:
-		sql = gda_mysql_render_DROP_VIEW (provider, cnc, op, error);
-		break;
+                sql = gda_mysql_render_DROP_VIEW (provider, cnc, op, error);
+                break;
         default:
                 g_assert_not_reached ();
         }
@@ -1024,7 +1014,7 @@ gda_mysql_provider_perform_operation (GdaServerProvider               *provider,
 			g_free (sql);
 			
 			if (res) {
-			  g_set_error (error, 0, 0, "%s", mysql_error (mysql));
+				g_set_error (error, 0, 0, mysql_error (mysql));
 				mysql_close (mysql);
 				return FALSE;
 			}
@@ -2196,12 +2186,12 @@ my_remove_quotes (gchar *str)
 
         total = strlen (str);
         if (str[total-1] == delim) {
-		/* string is correctly terminated */
+		/* string is correclty terminated */
 		g_memmove (str, str+1, total-2);
 		total -=2;
 	}
 	else {
-		/* string is _not_ correctly terminated */
+		/* string is _not_ correclty terminated */
 		g_memmove (str, str+1, total-1);
 		total -=1;
 	}
