@@ -212,8 +212,7 @@ gda_postgres_provider_class_init (GdaPostgresProviderClass *klass)
         provider_class->delete_savepoint = gda_postgres_provider_delete_savepoint;
 
 	provider_class->create_parser = gda_postgres_provider_create_parser;
-	provider_class->statement_to_sql = NULL; /* don't use gda_postgres_provider_statement_to_sql()
-						  * because it only calls gda_statement_to_sql_extended() */
+	provider_class->statement_to_sql = gda_postgres_provider_statement_to_sql;
 	provider_class->statement_prepare = gda_postgres_provider_statement_prepare;
 	provider_class->statement_execute = gda_postgres_provider_statement_execute;
 
@@ -641,8 +640,6 @@ gda_postgres_provider_open_connection (GdaServerProvider *provider, GdaConnectio
 		pq_pwd = gda_quark_list_find (params, "PASSWORD");
 
         pq_requiressl = gda_quark_list_find (params, "USE_SSL");
-	if (pq_requiressl && (*pq_requiressl != 'T') && (*pq_requiressl != 't'))
-		pq_requiressl = NULL;
 
 	/* TODO: Escape single quotes and backslashes in the user name and password: */
         conn_string = g_strconcat ("",
@@ -1603,9 +1600,6 @@ gda_postgres_provider_create_parser (GdaServerProvider *provider, GdaConnection
  * The implementation show here simply calls gda_statement_to_sql_extended() but the rendering
  * can be specialized to the database's SQL dialect, see the implementation of gda_statement_to_sql_extended()
  * and SQLite's specialized rendering for more details
- *
- * NOTE: This implementation MUST NOT call gda_statement_to_sql_extended() if it is
- *       the GdaServerProvider::statement_to_sql() virtual method's implementation
  */
 static gchar *
 gda_postgres_provider_statement_to_sql (GdaServerProvider *provider, GdaConnection *cnc,
