@@ -1,5 +1,5 @@
 /* GDA Capi provider
- * Copyright (C) 2008 - 2009 The GNOME Foundation.
+ * Copyright (C) 2008 The GNOME Foundation.
  *
  * AUTHORS:
  *      TO_ADD: your name and email
@@ -185,10 +185,7 @@ gda_capi_provider_class_init (GdaCapiProviderClass *klass)
         provider_class->delete_savepoint = gda_capi_provider_delete_savepoint;
 
 	provider_class->create_parser = gda_capi_provider_create_parser;
-	provider_class->statement_to_sql = NULL; /* don't use gda_capi_provider_statement_to_sql()
-						  * because it only calls gda_statement_to_sql_extended().
-						  * Set it to gda_capi_provider_statement_to_sql() if it does
-						  * not call calls gda_statement_to_sql_extended() */
+	provider_class->statement_to_sql = gda_capi_provider_statement_to_sql;
 	provider_class->statement_prepare = gda_capi_provider_statement_prepare;
 	provider_class->statement_execute = gda_capi_provider_statement_execute;
 
@@ -239,10 +236,6 @@ gda_capi_provider_class_init (GdaCapiProviderClass *klass)
 	provider_class->meta_funcs.routine_col = _gda_capi_meta_routine_col;
 	provider_class->meta_funcs._routine_par = _gda_capi_meta__routine_par;
 	provider_class->meta_funcs.routine_par = _gda_capi_meta_routine_par;
-	provider_class->meta_funcs._indexes_tab = _gda_capi_meta__indexes_tab;
-        provider_class->meta_funcs.indexes_tab = _gda_capi_meta_indexes_tab;
-        provider_class->meta_funcs._index_cols = _gda_capi_meta__index_cols;
-        provider_class->meta_funcs.index_cols = _gda_capi_meta_index_cols;
 
 	/* distributed transactions: if not supported, then provider_class->xa_funcs should be set to NULL */
 	provider_class->xa_funcs = g_new0 (GdaServerProviderXa, 1);
@@ -890,9 +883,6 @@ gda_capi_provider_create_parser (GdaServerProvider *provider, GdaConnection *cnc
  * The implementation show here simply calls gda_statement_to_sql_extended() but the rendering
  * can be specialized to the database's SQL dialect, see the implementation of gda_statement_to_sql_extended()
  * and SQLite's specialized rendering for more details
- *
- * NOTE: This implementation MUST NOT call gda_statement_to_sql_extended() if it is
- *       the GdaServerProvider::statement_to_sql() virtual method's implementation
  */
 static gchar *
 gda_capi_provider_statement_to_sql (GdaServerProvider *provider, GdaConnection *cnc,
