@@ -88,6 +88,9 @@ main (int argc, char **argv)
 	gint i, ntests = 0, number_failed = 0;
 	GdaConnection *cnc;
 
+	/* set up test environment */
+        g_setenv ("GDA_TOP_BUILD_DIR", TOP_BUILD_DIR, 0);
+	g_setenv ("GDA_TOP_SRC_DIR", TOP_SRC_DIR, TRUE);
 	gda_init ();
 
 	g_unlink ("pmodel.db");
@@ -300,7 +303,7 @@ static gint
 test2 (GdaConnection *cnc)
 {
 	GError *error = NULL;
-	GdaDataModel *model = NULL;
+	GdaDataModel *model;
 	GdaStatement *stmt, *mod_stmt;
 	gint nfailed = 0;
 	GdaSet *params;
@@ -359,15 +362,14 @@ test2 (GdaConnection *cnc)
 	if (!gda_data_select_set_modification_statement (GDA_DATA_SELECT (model), mod_stmt, &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_set_modification_statement() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_set_modification_statement() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
 	}
 
- out:
-	if (model)
-		g_object_unref (model);
+ out:	
+	g_object_unref (model);
 	g_object_unref (stmt);
 	
 	return nfailed;
@@ -409,7 +411,7 @@ test3 (GdaConnection *cnc)
 	if (!gda_data_select_set_modification_statement (GDA_DATA_SELECT (model), mod_stmt, &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_set_modification_statement() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_set_modification_statement() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -501,7 +503,7 @@ test4 (GdaConnection *cnc)
 	if (!gda_data_select_set_modification_statement (GDA_DATA_SELECT (model), mod_stmt, &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_set_modification_statement() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_set_modification_statement() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -511,7 +513,7 @@ test4 (GdaConnection *cnc)
 	if (! gda_data_model_remove_row (model, 0, &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_model_remove_row() should have succeeded, error: %s\n",
+		g_print ("gda_data_model_remove_row() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		g_error_free (error);
@@ -566,7 +568,7 @@ test5 (GdaConnection *cnc)
 	if (!gda_data_select_set_modification_statement (GDA_DATA_SELECT (model), mod_stmt, &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_set_modification_statement() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_set_modification_statement() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -689,7 +691,7 @@ test6 (GdaConnection *cnc)
 	if (! gda_data_select_set_row_selection_condition_sql (GDA_DATA_SELECT (model), "id = ##-0::gint", &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_set_row_selection_condition_sql() have succeeded, error: %s\n",
+		g_print ("gda_data_select_set_row_selection_condition_sql() have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -715,7 +717,7 @@ test6 (GdaConnection *cnc)
 	if (!gda_data_select_set_modification_statement (GDA_DATA_SELECT (model), mod_stmt, &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_set_modification_statement() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_set_modification_statement() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -810,7 +812,7 @@ static gint
 test7 (GdaConnection *cnc)
 {
 	GError *error = NULL;
-	GdaDataModel *model = NULL;
+	GdaDataModel *model;
 	GdaStatement *stmt;
 	gint nfailed = 0;
 	GdaSet *params;
@@ -852,7 +854,7 @@ test7 (GdaConnection *cnc)
 	if (!gda_data_select_compute_modification_statements (GDA_DATA_SELECT (model), &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_compute_modification_statements() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_compute_modification_statements() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -866,9 +868,8 @@ test7 (GdaConnection *cnc)
 	}
 	gda_value_free (value);
 
- out:
-	if (model)
-		g_object_unref (model);
+ out:	
+	g_object_unref (model);
 	g_object_unref (stmt);
 	g_object_unref (params);
 	
@@ -910,7 +911,7 @@ test8 (GdaConnection *cnc)
 	if (!gda_data_select_compute_modification_statements (GDA_DATA_SELECT (model), &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_set_modification_statement() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_set_modification_statement() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -947,7 +948,7 @@ static gint
 test9 (GdaConnection *cnc)
 {
 	GError *error = NULL;
-	GdaDataModel *model = NULL;
+	GdaDataModel *model;
 	GdaStatement *stmt;
 	gint nfailed = 0;
 	GdaSet *params;
@@ -989,7 +990,7 @@ test9 (GdaConnection *cnc)
 	if (!gda_data_select_compute_modification_statements (GDA_DATA_SELECT (model), &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_compute_modification_statements() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_compute_modification_statements() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -1015,9 +1016,8 @@ test9 (GdaConnection *cnc)
 	gda_value_free (value);
 	clear_signals ();
 
- out:
-	if (model)
-		g_object_unref (model);
+ out:	
+	g_object_unref (model);
 	g_object_unref (stmt);
 	g_object_unref (params);
 	
@@ -1034,7 +1034,7 @@ static gint
 test10 (GdaConnection *cnc)
 {
 	GError *error = NULL;
-	GdaDataModel *model = NULL, *copy;
+	GdaDataModel *model, *copy;
 	GdaStatement *stmt;
 	gint nfailed = 0;
 	GdaSet *params;
@@ -1102,9 +1102,8 @@ test10 (GdaConnection *cnc)
 	g_object_unref (cmp);
 	g_object_unref (copy);
 
- out:
-	if (model)
-		g_object_unref (model);
+ out:	
+	g_object_unref (model);
 	g_object_unref (stmt);
 	g_object_unref (params);
 	
@@ -1120,7 +1119,7 @@ static gint
 test11 (GdaConnection *cnc)
 {
 	GError *error = NULL;
-	GdaDataModel *ramodel = NULL, *model = NULL;
+	GdaDataModel *ramodel, *model;
 	GdaStatement *stmt;
 	gint nfailed = 0;
 	GdaSet *params;
@@ -1221,11 +1220,9 @@ test11 (GdaConnection *cnc)
 	}
 	g_object_unref (iter);
 
- out:
-	if (ramodel)
-		g_object_unref (ramodel);
-	if (model)
-		g_object_unref (model);
+ out:	
+	g_object_unref (ramodel);
+	g_object_unref (model);
 	g_object_unref (stmt);
 	g_object_unref (params);
 	
@@ -1271,7 +1268,7 @@ test12 (GdaConnection *cnc)
 	if (!gda_data_select_compute_modification_statements (GDA_DATA_SELECT (model), &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_compute_modification_statements() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_compute_modification_statements() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -1411,7 +1408,7 @@ test13 (GdaConnection *cnc)
 	if (!gda_data_select_set_modification_statement (GDA_DATA_SELECT (model), mod_stmt, &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_set_modification_statement() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_set_modification_statement() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -1506,7 +1503,7 @@ test14 (GdaConnection *cnc)
 	if (!gda_data_select_compute_modification_statements (GDA_DATA_SELECT (model), &error)) {
 		nfailed++;
 #ifdef CHECK_EXTRA_INFO
-		g_print ("gda_data_select_compute_modification_statements() should have succeeded, error: %s\n",
+		g_print ("gda_data_select_compute_modification_statements() should have succedded, error: %s\n",
 			 error && error->message ? error->message : "No detail");
 #endif
 		goto out;
@@ -1573,7 +1570,7 @@ static gint
 test15 (GdaConnection *cnc)
 {
 	GError *error = NULL;
-        GdaDataModel *model = NULL, *rerun;
+        GdaDataModel *model, *rerun;
         GdaStatement *stmt;
         GdaSet *params;
         gint nfailed = 0;
@@ -1634,8 +1631,7 @@ test15 (GdaConnection *cnc)
         g_object_unref (rerun);
 
  out:
-	if (model)
-		g_object_unref (model);
+        g_object_unref (model);
         g_object_unref (stmt);
 
         return nfailed;
